# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).
{
  pkgs,
  lib,
  niri,
  lix-module,
  rs-programs,
  ...
}:
with lib;
with builtins;
{
  imports = [ lix-module.nixosModules.default ];

  environment = {
    systemPackages = with pkgs; [
      nixfmt-rfc-style
      overskride
      transmission_4-gtk

      htmlq

      ausweisapp
      prusa-slicer
      wget
      git
      hyfetch
      pciutils
      zip
      unzip
      gnutar
      iw
      btop
      nodejs

      cmatrix
      sl
      lolcat
      cool-retro-term

      jetbrains.idea-ultimate
      jdk

      libsecret
      fzf
      ripgrep
      appimage-run
      git-crypt
      file
      whois
      p7zip
      file
      tree
      socat
      smartmontools
      mprocs
      dig
      aria2
      cyme
      numbat
      devd

      libjxl

      s10e-jrnl

      ungoogled-chromium
      scc
      speedtest-rs
    ];
  };

  hardware.graphics.enable = true;

  services = {
    systemd-lock-handler.enable = true;
    openssh = {
      enable = true;
      settings.PasswordAuthentication = false;
      settings.KbdInteractiveAuthentication = false;
    };
  };

  programs = {
    ssh.startAgent = false;
    gnupg.agent = {
      enable = true;
      enableSSHSupport = true;
    };

    dconf.enable = true;
    mtr.enable = true;
  };

  hardware.gpgSmartcards.enable = true;

  boot.kernel.sysctl."vm.max_map_count" = 2147483642;

  hardware = {
    uinput.enable = true;
    bluetooth.enable = true;
  };

  security.rtkit.enable = true;

  users.users.jade = {
    isNormalUser = true;
    extraGroups = [
      "wheel"
      "input"
      "uinput"
      "libvirtd"
      "adbusers"
      "dialout"
      "plugdev"
      "wireshark"
    ];
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIOaE8TFsIazpn4OnHvHcRpOFr9FfvMaWOiEjmHsmnAoE cardno:000F_70CD7D05"
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILg7hhAKxIAbokHHcIj9HBgbkgoKGCG2R+gx7HZKL+iz cardno:000F_93C6A612"
    ];
  };

  zramSwap = {
    enable = true;
    algorithm = "zstd";
  };
}
